@@ -3,7 +3,6 @@ from allauth.socialaccount.models import SocialApp
 from django.contrib.sites.models import Site
 from django.core.management.base import BaseCommand
 
-from enough.common.openstack import OpenStack
 from enough.common.gitlab import GitLab
 
 
@@ -39,14 +38,9 @@ class Command(BaseCommand):
 
         return True
 
-    def setup_hosting(self, *args, **kwargs):
-        o = OpenStack(settings.CONFIG_DIR, f"{kwargs['config']}/api/hosting/clouds.yml")
-        return o.generate_clouds(f"{kwargs['config']}/api/hosting/all")
-
     def handle(self, *args, **kwargs):
         changed = False
         changed |= self.setup_gitlab_auth(*args, **kwargs)
-        changed |= self.setup_hosting(*args, **kwargs)
 
         if changed:
             self.stdout.write('Changed')
