@@ -44,7 +44,10 @@ class HostOpenStack(Host):
         h = openstack.Heat(self.config_dir, **self.args)
         complete_deletion = []
         for name in names:
-            s = openstack.Stack(self.config_dir, h.get_stack_definition(name), **self.args)
+            definition = h.get_stack_definition(name)
+            if not definition:
+                continue
+            s = openstack.Stack(self.config_dir, definition, **self.args)
             if s.delete_no_wait():
                 complete_deletion.append(name)
         for name in complete_deletion:
