@@ -2,6 +2,7 @@ import libvirt
 import logging
 import os
 import sh
+import tempfile
 import textwrap
 
 from enough.common.ssh import SSH
@@ -70,7 +71,6 @@ class Libvirt(object):
             },
         }
         self.virsh = sh.virsh.bake('--connect', self.uri, **bake_args)
-        self.virt_sysprep = sh.virt_sysprep.bake('--connect', self.uri, **bake_args)
         self.virt_install = sh.virt_install.bake('--connect', self.uri, **bake_args)
         self.sh_args = bake_args
         self.ssh = self.ansible.get_global_variable('libvirt_ssh')
@@ -85,8 +85,8 @@ class Libvirt(object):
             # ssh runs the arguments via the shell and evaluation will happen
             # add quote to make sure there is no evalution
             #
-            ssh_args = self.ssh[1:] + [f"'{a}'" for a in args]
-            return sh.Command(self.ssh[0])(*ssh_args, **self.sh_args)
+            ssh_args = self.ssh + [f"'{a}'" for a in args]
+            return sh.ssh(*ssh_args, **self.sh_args)
         else:
             sh.Command(args[0])(*args[1:], **self.sh_args)
 
@@ -109,18 +109,32 @@ class Libvirt(object):
         return f'{self.images_dir}/{name}-snapshot.qcow2'
 
     def public_key(self):
-        return f'{self.config_dir}/infrastructure_key.pub'
+        return open(f'{self.config_dir}/infrastructure_key.pub').read().strip()
+
+    def network_script_path(self):
+        path = f'{self.share_dir}/playbooks/infrastructure/network.sh'
+        if self.ssh:
+            remote_path = "/tmp/network.sh"
+            with tempfile.NamedTemporaryFile() as fp:
+                fp.write(f'put {path} {remote_path}\n'.encode('ascii'))
+                fp.flush()
+                args = ["-b", fp.name] + self.ssh
+                sh.sftp(*args, **self.sh_args)
+            return remote_path
+        else:
+            return path
 
     def sysprep(self, name, definition):
         fqdn = f'{name}.{self.domain}'
-        self.virt_sysprep(
+        self.shell(
+            'virt-sysprep',
             '-a', self.host_image_name(name),
             '--enable', 'customize',
             '--no-network',
             '--hostname', fqdn,
             '--run-command', f'sed -i -e "s/^127.0.1.1.*/127.0.1.1 {fqdn}/" /etc/hosts',
-            '--ssh-inject', f'debian:file:{self.public_key()}',
-            '--copy-in', f'{self.share_dir}/playbooks/infrastructure/network.sh:/root',
+            '--ssh-inject', f'debian:string:{self.public_key()}',
+            '--copy-in', f'{self.network_script_path()}:/root',
             '--firstboot-command', ('env '
                                     f'PORT={definition["port"]} '
                                     f'ROUTED={definition["network_interface_routed"]} '
