@@ -370,7 +370,8 @@ class OpenStack(OpenStackBase):
                                  for x in json.loads(r.stdout)]:
                 if prefix is None or prefix in name:
                     leftovers.append(f'stack({name})')
-                    if status == 'DELETE_FAILED' or not status.startswith('DELETE'):
+                    if status == 'DELETE_FAILED' or (
+                            status is not None and not status.startswith('DELETE')):
                         self.o.stack.delete('--yes', '--wait', name)
 
         def delete_images():
