@@ -13,7 +13,7 @@ def pytest_addoption(parser):
         "--enough-hosts",
         action="store",
 
-        default="bind-host,gitea-host",
+        default="bind-host,forgejo-host",
         help="list of hosts"
     )
     parser.addoption(
