@@ -42,7 +42,7 @@ def retry(exceptions, tries=2, delay=1):
     return deco_retry
 
 
-class Gitea(object):
+class Forgejo(object):
     def __init__(self, hostname):
         self._hostname = hostname
         self._url = f'https://{hostname}'
@@ -131,13 +131,13 @@ class Gitea(object):
             return False
 
     def projects_factory(self):
-        return GiteaProjects
+        return ForgejoProjects
 
     def users_factory(self):
-        return GiteaUsers
+        return ForgejoUsers
 
 
-class GiteaUsers(object):
+class ForgejoUsers(object):
     def __init__(self, forge):
         self._forge = forge
 
@@ -160,7 +160,7 @@ class GiteaUsers(object):
             return None
         else:
             r.raise_for_status()
-            return GiteaUser(self.forge, r.json())
+            return ForgejoUser(self.forge, r.json())
 
     def delete(self, username):
         user = self.get(username)
@@ -178,7 +178,7 @@ class GiteaUsers(object):
 
     def create(self, username, password, email, **data):
         # the API does not support creating an admin user
-        assert data.get("admin") is not True, "Creating an admin user with Gitea is not implemented"
+        assert data.get("admin") is not True, "Creating admin user with Forgejo is not implemented"
         info = self.get(username)
         if info is None:
             r = self.s.post(
@@ -193,7 +193,7 @@ class GiteaUsers(object):
                 logger.error(r.text)
             r.raise_for_status()
             info = r.json()
-            Gitea(self.forge.hostname).certs(self.s.verify).users._finalize_user_create(
+            Forgejo(self.forge.hostname).certs(self.s.verify).users._finalize_user_create(
                 username, password)
             info = self.get(username)
         return info
@@ -223,10 +223,10 @@ class GiteaUsers(object):
         j = r.json()
         assert j["ok"]
         for u in j["data"]:
-            yield GiteaUser(self.forge, u)
+            yield ForgejoUser(self.forge, u)
 
 
-class GiteaUser(object):
+class ForgejoUser(object):
     def __init__(self, forge, user):
         self._forge = forge
         self._user = user
@@ -249,7 +249,7 @@ class GiteaUser(object):
 
     def __eq__(self, other):
         return (
-            isinstance(other, GiteaUser)
+            isinstance(other, ForgejoUser)
             and self.forge == other.forge
             and self.url == other.url
             and self.username == other.username
@@ -319,10 +319,10 @@ class GiteaUser(object):
         raw = projects.json()
         assert raw["ok"]
         for project in raw["data"]:
-            yield GiteaProject(self.forge, project)
+            yield ForgejoProject(self.forge, project)
 
 
-class GiteaProjects(object):
+class ForgejoProjects(object):
     def __init__(self, forge):
         self._forge = forge
 
@@ -335,7 +335,7 @@ class GiteaProjects(object):
         return self.forge.s
 
     def project_factory(self):
-        return GiteaProject
+        return ForgejoProject
 
     def get(self, namespace, project):
         r = self.s.get(f"{self.s.api}/repos/{namespace}/{project}")
@@ -383,14 +383,14 @@ class GiteaProjects(object):
         raw = projects.json()
         assert raw["ok"]
         for project in raw["data"]:
-            yield GiteaProject(self.forge, project)
+            yield ForgejoProject(self.forge, project)
 
 
-class GiteaProject(object):
+class ForgejoProject(object):
     def __init__(self, forge, project):
         self._forge = forge
         self._project = project
-        self._keys = GiteaProjectKeys(self)
+        self._keys = ForgejoProjectKeys(self)
 
     @property
     def forge(self):
@@ -438,7 +438,7 @@ class GiteaProject(object):
 
     def __eq__(self, other):
         return (
-            isinstance(other, GiteaProject)
+            isinstance(other, ForgejoProject)
             and self.id == other.id
             and self.namespace == other.namespace
             and self.project == other.project
@@ -447,7 +447,7 @@ class GiteaProject(object):
         )
 
 
-class GiteaProjectKeys(object):
+class ForgejoProjectKeys(object):
     def __init__(self, project):
         self._project = project
 
@@ -468,7 +468,7 @@ class GiteaProjectKeys(object):
             return None
         else:
             response.raise_for_status()
-            return GiteaProjectKey(self.project, response.json())
+            return ForgejoProjectKey(self.project, response.json())
 
     def delete(self, id):
         p = self.get(id)
@@ -501,10 +501,10 @@ class GiteaProjectKeys(object):
         response = self.s.get(f"{self._build_url()}")
         response.raise_for_status()
         for key in response.json():
-            yield GiteaProjectKey(self.project, key)
+            yield ForgejoProjectKey(self.project, key)
 
 
-class GiteaProjectKey(object):
+class ForgejoProjectKey(object):
     def __init__(self, project, key):
         self._project = project
         self._key = key
@@ -527,13 +527,13 @@ class GiteaProjectKey(object):
 
     def __eq__(self, other):
         return (
-            isinstance(other, GiteaProjectKey)
+            isinstance(other, ForgejoProjectKey)
             and self.id == other.id
             and self.title == other.title
         )
 
 
-class GiteaBrowser(object):
+class ForgejoBrowser(object):
 
     def __init__(self, hostname, user, password, certs):
         self.hostname = hostname
@@ -543,12 +543,12 @@ class GiteaBrowser(object):
 
     def login(self):
         #
-        # This is **different** from Gitea.authenticate() which
+        # This is **different** from Forgejo.authenticate() which
         # obtains a token for API interactions. It is limited to
         # simulating user browsing.
         #
         #
-        # Gitea home page
+        # Forgejo home page
         #
         self.g = requests.Session()
         self.g.verify = self.certs
@@ -560,7 +560,7 @@ class GiteaBrowser(object):
             'form[action="/user/login"] input[name="_csrf"]')[0]['value']
 
         #
-        # Gitea Login
+        # Forgejo Login
         #
         r = self.g.post(self.g.url + '/user/login', data={
             '_csrf': csrf,
@@ -580,8 +580,6 @@ class GiteaBrowser(object):
         r = self.g.get(self.g.url + '/user/settings/applications')
         r.raise_for_status()
         soup = BeautifulSoup(r.text, 'html.parser')
-        csrf = soup.select(
-            'form[action="/user/settings/applications"] input[name="_csrf"]')[0]['value']
         revoked = []
         for b in soup.select('button[data-modal-id="revoke-gitea-oauth2-grant"]'):
             found = b.parent.parent.select('.content strong')
@@ -591,14 +589,9 @@ class GiteaBrowser(object):
                 logger.info(f"{found[0]} does not contain {name}, skipping")
                 continue
 
-            id = b["data-id"]
-            data = {
-                "id": id,
-                '_csrf': csrf,
-            }
-            logger.info(f"revoking grant id {id} for application {name}")
-            r = self.g.post(self.g.url + "/user/settings/applications/oauth2/revoke",
-                            data=data)
+            url = b["data-url"]
+            logger.info(f"revoking grant {url} for application {name}")
+            r = self.g.post(self.g.url + url)
             r.raise_for_status()
             revoked.append(id)
         return revoked
@@ -640,9 +633,9 @@ class Woodpecker(object):
     # The API is undocumented and must be read from woodpecker/server/router/api.go
     #
 
-    def __init__(self, gitea_browser, gitea_user, hostname, certs):
-        self.gitea_browser = gitea_browser
-        self.gitea_user = gitea_user
+    def __init__(self, forgejo_browser, forgejo_user, hostname, certs):
+        self.forgejo_browser = forgejo_browser
+        self.forgejo_user = forgejo_user
         self.hostname = hostname
         self.certs = certs
 
@@ -654,9 +647,9 @@ class Woodpecker(object):
                        allow_redirects=False)
         r.raise_for_status()
         #
-        # Gitea OAuth confirmation page
+        # Forgejo OAuth confirmation page
         #
-        location = self.gitea_browser.confirm_oauth(
+        location = self.forgejo_browser.confirm_oauth(
             r.headers['Location'],
             f"https://{self.hostname}/authorize")
         r = self.w.get(location, allow_redirects=False)
@@ -683,19 +676,20 @@ class Woodpecker(object):
     def refresh(self):
         self.w.get(self.w.url + "/api/user/repos?all=true&flush=true").raise_for_status()
 
-    def build_logs(self, project, sha, step):
-        url = self.w.url + f"/api/repos/{self.gitea_user}/{project}"
+    def pipeline_logs(self, project, sha, step):
+        url = self.w.url + f"/api/repos/{self.forgejo_user}/{project}"
 
         @retry(AssertionError, tries=4)
-        def wait_for_build():
-            r = self.w.get(f"{url}/builds")
+        def wait_for_pipeline():
+            r = self.w.get(f"{url}/pipelines")
             r.raise_for_status()
-            for build in r.json():
-                if build['commit'] == sha:
-                    return build['number']
-            assert 0, f"build with commit {sha} not found in {r.text}"
-        number = wait_for_build()
-        r = self.w.get(f"{url}/builds/{number}")
+            logger.debug(f"pipelines {r.text}")
+            for pipeline in r.json():
+                if pipeline['commit'] == sha:
+                    return pipeline['number']
+            assert 0, f"pipeline with commit {sha} not found in {r.text}"
+        number = wait_for_pipeline()
+        r = self.w.get(f"{url}/pipelines/{number}")
         r.raise_for_status()
 
         def get_pid(children):
@@ -703,7 +697,7 @@ class Woodpecker(object):
                 if proc["name"] == step:
                     return proc["pid"]
             raise Exception(f"no children named {proc['name']} in {children}")
-        pid = get_pid(r.json()["procs"][0]["children"])
+        pid = get_pid(r.json()["steps"][0]["children"])
 
         @retry(AssertionError, tries=4)
         def wait_for_logs():
@@ -719,34 +713,34 @@ class Woodpecker(object):
 
     def disable_project(self, project):
         self.refresh()
-        r = self.w.get(self.w.url + f"/api/repos/{self.gitea_user}/{project}")
+        r = self.w.get(self.w.url + f"/api/repos/{self.forgejo_user}/{project}")
         r.raise_for_status()
         logger.info(f"disable project {project} {r.text}")
         if r.json()['active'] is False:
             return False
-        self.w.delete(self.w.url + f"/api/repos/{self.gitea_user}/{project}").raise_for_status()
+        self.w.delete(self.w.url + f"/api/repos/{self.forgejo_user}/{project}").raise_for_status()
         return True
 
     def enable_project(self, project):
         self.refresh()
-        r = self.w.get(self.w.url + f"/api/repos/{self.gitea_user}/{project}")
+        r = self.w.get(self.w.url + f"/api/repos/{self.forgejo_user}/{project}")
         r.raise_for_status()
         logger.info(f"enabling project {project} {r.text}")
         if r.json()['active'] is True:
             return False
-        self.w.post(self.w.url + f"/api/repos/{self.gitea_user}/{project}").raise_for_status()
-        self.w.patch(self.w.url + f"/api/repos/{self.gitea_user}/{project}",
+        self.w.post(self.w.url + f"/api/repos/{self.forgejo_user}/{project}").raise_for_status()
+        self.w.patch(self.w.url + f"/api/repos/{self.forgejo_user}/{project}",
                      json={
                          "trusted": True,
                          "visibility": "internal",
                      }).raise_for_status()
-        r = self.w.get(self.w.url + f"/api/repos/{self.gitea_user}/{project}")
+        r = self.w.get(self.w.url + f"/api/repos/{self.forgejo_user}/{project}")
         r.raise_for_status()
         logger.info(f"enabled project {project} {r.text}")
         return True
 
     def add_secret(self, project, name, value, events):
-        r = self.w.post(self.w.url + f"/api/repos/{self.gitea_user}/{project}/secrets",
+        r = self.w.post(self.w.url + f"/api/repos/{self.forgejo_user}/{project}/secrets",
                         json={
                             "event": events,
                             "name": name,
@@ -757,7 +751,7 @@ class Woodpecker(object):
         return True
 
     def list_secrets(self, project):
-        r = self.w.get(self.w.url + f"/api/repos/{self.gitea_user}/{project}/secrets")
+        r = self.w.get(self.w.url + f"/api/repos/{self.forgejo_user}/{project}/secrets")
         r.raise_for_status()
         for secret in r.json():
             yield secret
@@ -766,7 +760,7 @@ class Woodpecker(object):
         for secret in self.list_secrets(project):
             if secret["name"] == name:
                 r = self.w.delete(
-                    self.w.url + f"/api/repos/{self.gitea_user}/{project}/secrets/{name}")
+                    self.w.url + f"/api/repos/{self.forgejo_user}/{project}/secrets/{name}")
                 r.raise_for_status()
                 logger.info(f"deleted secret {name} from project {project} {r.text}")
                 return True
@@ -776,7 +770,7 @@ class Woodpecker(object):
 @dataclass
 class Hostea(object):
     certs: str
-    gitea_hostname: str
+    forgejo_hostname: str
     admin_user: str
     admin_password: str
     user: str
@@ -791,10 +785,10 @@ class Hostea(object):
     debug: bool = False
 
     def setup(self):
-        self.gitea_create()
-        self.gitea_user_create()
-        self.gitea_project_create()
-        self.gitea_add_deploy()
+        self.forgejo_create()
+        self.forgejo_user_create()
+        self.forgejo_project_create()
+        self.forgejo_add_deploy()
         self.woodpecker_auth()
         self.woodpecker_save_token()
         self.woodpecker_enable_project()
@@ -802,12 +796,12 @@ class Hostea(object):
         self.woodpecker_add_enough()
 
     def destroy(self):
-        self.gitea_create()
-        self.gitea.authenticate(username=self.admin_user, password=self.admin_password)
-        if self.gitea.users.get(self.user):
+        self.forgejo_create()
+        self.forgejo.authenticate(username=self.admin_user, password=self.admin_password)
+        if self.forgejo.users.get(self.user):
             self.destroy_project()
-            self.gitea.users.delete(self.user)
-        self.gitea.logout()
+            self.forgejo.users.delete(self.user)
+        self.forgejo.logout()
 
     def update_project(self, content_dir):
         self.git_init_project()
@@ -842,7 +836,7 @@ class Hostea(object):
         self.git = sh.git.bake(_cwd=self.git_directory.name)
         self.git.init()
 
-        p = self.gitea.projects.get(self.user, self.project)
+        p = self.forgejo.projects.get(self.user, self.project)
         url = p.http_url_to_repo_with_auth
         self.git.config('http.sslVerify', 'false')
         self.git.remote.add.origin(url)
@@ -852,33 +846,33 @@ class Hostea(object):
     def destroy_project(self):
         self.woodpecker_auth()
         self.woodpecker_disable_project()
-        self.gitea_browser.revoke_application("woodpecker")
-        self.gitea.projects.delete(self.user, self.project)
+        self.forgejo_browser.revoke_application("woodpecker")
+        self.forgejo.projects.delete(self.user, self.project)
 
-    def gitea_create(self):
-        self.gitea = Gitea(self.gitea_hostname)
-        self.gitea.certs(self.certs)
+    def forgejo_create(self):
+        self.forgejo = Forgejo(self.forgejo_hostname)
+        self.forgejo.certs(self.certs)
 
-    def gitea_user_create(self):
-        self.gitea.authenticate(username=self.admin_user, password=self.admin_password)
-        self.gitea.users.create(self.user, self.password, self.email)
-        self.gitea.authenticate(username=self.user, password=self.password)
+    def forgejo_user_create(self):
+        self.forgejo.authenticate(username=self.admin_user, password=self.admin_password)
+        self.forgejo.users.create(self.user, self.password, self.email)
+        self.forgejo.authenticate(username=self.user, password=self.password)
 
-    def gitea_project_create(self):
-        return self.gitea.projects.create(self.user, self.project, private=True)
+    def forgejo_project_create(self):
+        return self.forgejo.projects.create(self.user, self.project, private=True)
 
-    def gitea_add_deploy(self):
-        return self.gitea.projects.get(self.user, self.project).keys.create(
+    def forgejo_add_deploy(self):
+        return self.forgejo.projects.get(self.user, self.project).keys.create(
             title="deploy",
             key=open(f"{self.deploy}.pub").read().strip(),
             read_only=False)
 
     def woodpecker_auth(self):
-        self.gitea_browser = GiteaBrowser(
-            self.gitea_hostname, self.user, self.password, self.certs)
-        self.gitea_browser.login()
+        self.forgejo_browser = ForgejoBrowser(
+            self.forgejo_hostname, self.user, self.password, self.certs)
+        self.forgejo_browser.login()
         self.woodpecker = Woodpecker(
-            self.gitea_browser, self.user, self.woodpecker_hostname, self.certs)
+            self.forgejo_browser, self.user, self.woodpecker_hostname, self.certs)
         self.woodpecker.login()
 
     def woodpecker_save_token(self):
@@ -918,7 +912,7 @@ def main(argv):
     parser.add_argument(
         '--update-directory',
         help='update the project repository with the content of this directory')
-    parser.add_argument('gitea_hostname')
+    parser.add_argument('forgejo_hostname')
     parser.add_argument('admin_user')
     parser.add_argument('admin_password')
     parser.add_argument('user')
@@ -940,7 +934,7 @@ def main(argv):
     hostea.setup()
     if update_directory:
         hostea.update_project(update_directory)
-    return (hostea.gitea, hostea.woodpecker)
+    return (hostea.forgejo, hostea.woodpecker)
 
 
 if __name__ == '__main__':
