@@ -12,9 +12,9 @@ from playbooks.hostea.tests.test_hostea import (
     get_fleet_domain,
 )
 from playbooks.hosteadashboard.tests.hostea import Hostea
-from playbooks.hosteadashboard.tests.gitea import GiteaSSO
+from playbooks.hosteadashboard.tests.forgejo import ForgejoSSO
 
-testinfra_hosts = ['ansible://gitea-host']
+testinfra_hosts = ['ansible://forgejo-host']
 
 
 def get_domain(inventory):
@@ -26,10 +26,10 @@ def test_hosteadashboard_create_delete_vm(pytestconfig, host, tmpdir):
     #
     # Wait for the DNS to answer
     #
-    gitea_domain = get_domain(pytestconfig.getoption("--ansible-inventory"))
+    forgejo_domain = get_domain(pytestconfig.getoption("--ansible-inventory"))
     d = f"{tmpdir}/hostea"
     git = sh.git.bake("-c", "http.sslVerify=false")
-    wait_for_bootstrap(git, d, gitea_domain)
+    wait_for_bootstrap(git, d, forgejo_domain)
 
     #
     # What is its domain name?
@@ -51,37 +51,37 @@ def test_hosteadashboard_create_delete_vm(pytestconfig, host, tmpdir):
             assert 0 == cmd.rc
 
     #
-    # Ask the dashboard to create a new Gitea instance
+    # Ask the dashboard to create a new Forgejo instance
     #
     vm = "thevm"
     manage_vm(f"create {vm} --owner=adminuser --flavor=small")
 
     #
-    # Wait until the Gitea instance is ready
+    # Wait until the Forgejo instance is ready
     #
     @retry.retry(AssertionError, tries=60, delay=30, exponential=False)
-    def wait_for_fleet(git, d, gitea_domain):
+    def wait_for_fleet(git, d, forgejo_domain):
         #
         # Wait for the IP of the host to be added to the repository, which indicates
         # hostea.sh completed. This may happen *after* the DNS resolves the fqdn
         #
         shutil.rmtree(d, ignore_errors=True)
-        git.clone(f"https://root:etquofEtseudett@gitea.{gitea_domain}/hostea/hostea", d)
+        git.clone(f"https://root:etquofEtseudett@forgejo.{forgejo_domain}/hostea/hostea", d)
         assert "the fleet was updated" in git("--no-pager", "-C", d, "log", "-1", "--oneline")
-    wait_for_fleet(git, d, gitea_domain)
+    wait_for_fleet(git, d, forgejo_domain)
 
     @retry.retry(AssertionError, tries=60, delay=30, exponential=False)
-    def wait_for_gitea():
+    def wait_for_forgejo():
         try:
             page = sh.curl("--max-time", "10", "--insecure", f"https://{vm}.{fleet_domain}")
-            assert "Gitea" in page
+            assert "Forgejo" in page
         except sh.ErrorReturnCode_6:
             assert 0, "cloud not resolve"
         except sh.ErrorReturnCode_28:
             assert 0, "timeout"
         except sh.ErrorReturnCode_7:
             assert 0, "Failed to connect"
-    wait_for_gitea()
+    wait_for_forgejo()
 
     #
     # An invoice is sent via email when it is due, which is right away when
@@ -94,14 +94,14 @@ def test_hosteadashboard_create_delete_vm(pytestconfig, host, tmpdir):
     print(cmd.stderr)
     assert 0 == cmd.rc
     with host.sudo():
-        cmd = host.run("grep 'An invoice is generated' /var/spool/postfix/deferred/*/*")
+        cmd = host.run("grep 'Payment receipt' /var/spool/postfix/deferred/*/*")
         print(cmd.stdout)
         print(cmd.stderr)
         assert 0 == cmd.rc
     with host.sudo():
         host.run("postsuper -d ALL")
     #
-    # Destroy the Gitea instance
+    # Destroy the Forgejo instance
     #
     manage_vm(f"delete {vm}")
 
@@ -113,7 +113,7 @@ def test_hosteadashboard_create_delete_vm(pytestconfig, host, tmpdir):
 
 
 def test_hosteadashboard_support(
-        pytestconfig, host, gitea_hostname, make_user, make_project, certs, tmpdir):
+        pytestconfig, host, forgejo_hostname, make_user, make_project, certs, tmpdir):
     domain = get_domain(pytestconfig.getoption("--ansible-inventory"))
 
     dash_username = "adminuser"
@@ -122,7 +122,7 @@ def test_hosteadashboard_support(
     dash_host = f"https://hosteadashboard.{domain}"
     dash_project = "support"
 
-    forge = hosteasetup.Gitea(gitea_hostname)
+    forge = hosteasetup.Forgejo(forgejo_hostname)
     forge.certs(certs)
     make_user(forge, dash_username, dash_password)
     forge.authenticate(username=dash_username, password=dash_password)
@@ -141,12 +141,12 @@ def test_hosteadashboard_support(
     )
     dash.login()
 
-    dash_gitea_sso = GiteaSSO(
+    dash_forgejo_sso = ForgejoSSO(
         username=dash_username,
         email=dash_email,
-        gitea_host=f"https://{gitea_hostname}",
+        forgejo_host=f"https://{forgejo_hostname}",
         hostea_org=dash_username,
         support_repo=dash_project,
         c=dash_c,
     )
-    dash_gitea_sso._sso_login()
+    dash_forgejo_sso._sso_login()
