@@ -19,3 +19,7 @@ class TestChecks(IcingaHelper):
 
     def test_proxy_host(self):
         assert 'proxy-host' in self.get_hosts(host='proxy-host')
+
+    def test_proxy_service(self):
+        assert self.is_service_ok('proxy-host!Proxy othername.website.test')
+        assert self.is_service_ok('proxy-host!Proxy theproxy.website.test')
